.. RicciPy documentation master file, created by
   sphinx-quickstart on Fri Jun 12 16:05:41 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

RicciPy: Symbolic Algebra for Lorentzian Manifolds
==================================================

*RicciPy* is a Python library for algebraically representing and manipulating
geometry on Lorentzian manifolds. RicciPy makes it as convenient as possible
for doing basic operations such as addition, multiplication, and contraction of
tensors on an arbitrary, Pseudo-Riemannian metric space.  In addition, RicciPy
also provides tools for doing analytical computations for objects such as the
Christoffel symbols and the Riemann/Weyl tensors of a given spacetime metric.

Not only does RicciPy provide the means for manipulating tensors/metrics,
RicciPy also provides a total of over 100 different representations for a
myriad of exact solutions to the Einstein Field Equations.


.. toctree::
    :maxdepth: 1
    :caption: Contents:

    installation
    concepts
    examples/index
    api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
